@@ -8,7 +8,7 @@
 // |                                                                           |
 // | Shows details of an event or events                                       |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2008 by dengen - taharaxp AT gmail DOT com                  |
+// | Copyright (C) 2008-2010 by dengen - taharaxp AT gmail DOT com             |
 // |                                                                           |
 // | Calendarjp plugin is based on prior work by:                              |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
@@ -65,23 +65,27 @@ function adduserevent ($eid)
         $retval .= COM_startBlock (sprintf ($LANG_CALJP_1[11],
                                             COM_getDisplayName()));
         $A = DB_fetchArray($result);
-        $cal_template = new Template($_CONF['path'] . 'plugins/calendarjp/templates/');
+        $cal_template = COM_newTemplate($_CONF['path'] . 'plugins/calendarjp/templates/');
         $cal_template->set_file(array('addevent' => 'addevent.thtml'));
-        $cal_template->set_var('xhtml', XHTML);
-        $cal_template->set_var('site_url', $_CONF['site_url']);
-        $cal_template->set_var('site_admin_url', $_CONF['site_admin_url']);
-        $cal_template->set_var('layout_url', $_CONF['layout_url']);
         $cal_template->set_var('intro_msg', $LANG_CALJP_1[8]);
         $cal_template->set_var('lang_event', $LANG_CALJP_1[12]);
-        $event_title = stripslashes($A['title']);
 
-        if (!empty ($A['url']) && ($A['url'] != 'http://')) {
-            $cal_template->set_var ('event_url', $A['url']);
-            $event_title = COM_createLink($event_title, $A['url']);
+        $event_title = stripslashes($A['title']);
+        if (!empty($A['url']) && ($A['url'] != 'http://')) {
+            $event_title_and_url = COM_createLink($event_title, $A['url'],
+                                                  array('class' => 'url'));
+            $cal_template->set_var('event_url', $A['url']);
+            $cal_template->set_var('event_begin_anchortag',
+                '<a href="' . $A['url'] . '" class="url">');
+            $cal_template->set_var('event_end_anchortag', '</a>');
         } else {
-            $cal_template->set_var ('event_url', '');
+            $event_title_and_url = $event_title;
+            $cal_template->set_var('event_url', '');
+            $cal_template->set_var('event_begin_anchortag', '');
+            $cal_template->set_var('event_end_anchortag', '');
         }
-        $cal_template->set_var ('event_title', $event_title);
+        $cal_template->set_var('event_title', $event_title_and_url);
+        $cal_template->set_var('event_title_only', $event_title);
         $cal_template->set_var('lang_starts', $LANG_CALJP_1[13]);
         $cal_template->set_var('lang_ends', $LANG_CALJP_1[14]);
 
@@ -137,7 +141,7 @@ function saveuserevent ($eid)
 {
     global $_CONF, $_TABLES, $_USER;
 
-    if (isset ($_USER['uid']) && ($_USER['uid'] > 1)) {
+    if (! COM_isAnonUser()) {
 
         // Try to delete the event first in case it has already been added
         DB_query ("DELETE FROM {$_TABLES['personal_eventsjp']} WHERE uid={$_USER['uid']} AND eid='$eid'");
@@ -155,7 +159,7 @@ function saveuserevent ($eid)
             DB_query ($savesql);
 
             return COM_refresh ($_CONF['site_url']
-                                . '/calendarjp/index.php?mode=personal&amp;msg=24');
+                                . '/calendarjp/index.php?mode=personal&msg=24');
         }
     }
 
@@ -173,12 +177,9 @@ function editpersonalevent ($A)
 {
     global $_CONF, $_CAJP_CONF, $LANG_CALJP_1;
 
-    $cal_templates = new Template($_CONF['path'] . 'plugins/calendarjp/templates/');
-    $cal_templates->set_file('form','editpersonalevent.thtml');
-    $cal_templates->set_var( 'xhtml', XHTML );
-    $cal_templates->set_var('site_url', $_CONF['site_url']);
-    $cal_templates->set_var('site_admin_url', $_CONF['site_admin_url']);
-    $cal_templates->set_var('layout_url', $_CONF['layout_url']);
+    $ja = ($_CONF['language'] == 'japanese_utf-8');
+    $cal_templates = COM_newTemplate($_CONF['path'] . 'plugins/calendarjp/templates/');
+    $cal_templates->set_file('form','editpersonalevent' . ($ja ? '_ja' : '') . '.thtml');
 
     $cal_templates->set_var ('lang_title', $LANG_CALJP_1[28]);
     $title = stripslashes ($A['title']);
@@ -268,6 +269,10 @@ function editpersonalevent ($A)
         $cal_templates->set_var ('allday_checked', '');
     }
 
+    $cal_templates->set_var('lang_tail_year', $LANG_CALJP_1['tail_year']);
+    $cal_templates->set_var('lang_tail_month', $LANG_CALJP_1['tail_month']);
+    $cal_templates->set_var('lang_tail_day', $LANG_CALJP_1['tail_day']);
+
     $cal_templates->set_var('lang_location',$LANG_CALJP_1[39]);
     $cal_templates->set_var('event_location', stripslashes ($A['location']));
 
@@ -388,7 +393,7 @@ case 'saveuserevent':
 
 case $LANG_CALJP_1[45]: // save edited personal event
     if (!empty($LANG_CALJP_1[45]) && ($_CAJP_CONF['personalcalendars'] == 1) &&
-            (!empty ($_USER['uid']) && ($_USER['uid'] > 1)) &&
+            !COM_isAnonUser() &&
             (isset ($_POST['calendar_type']) &&
              ($_POST['calendar_type'] == 'personal')) && SEC_checkToken()) {
         $display = plugin_savesubmission_calendarjp ($_POST);
@@ -401,10 +406,10 @@ case 'deleteevent':
 case $LANG_CALJP_1[51]:
     if (($_CAJP_CONF['personalcalendars'] == 1) && SEC_checkToken()) {
         $eid = COM_applyFilter ($_REQUEST['eid']);
-        if (!empty ($eid) && (isset ($_USER['uid']) && ($_USER['uid'] > 1))) {
+        if (!empty($eid) && !COM_isAnonUser()) {
             DB_query ("DELETE FROM {$_TABLES['personal_eventsjp']} WHERE uid={$_USER['uid']} AND eid='$eid'");
             $display .= COM_refresh ($_CONF['site_url']
-                     . '/calendarjp/index.php?mode=personal&amp;msg=26');
+                     . '/calendarjp/index.php?mode=personal&msg=26');
         } else {
             $display = COM_refresh ($_CONF['site_url'] . '/index.php');
         }
@@ -416,7 +421,7 @@ case $LANG_CALJP_1[51]:
 case 'edit':
     if ($_CAJP_CONF['personalcalendars'] == 1) {
         $eid = COM_applyFilter ($_GET['eid']);
-        if (!empty ($eid) && (isset ($_USER['uid']) && ($_USER['uid'] > 1))) {
+        if (!empty($eid) && !COM_isAnonUser()) {
             $result = DB_query ("SELECT * FROM {$_TABLES['personal_eventsjp']} WHERE (eid = '$eid') AND (uid = {$_USER['uid']})");
             if (DB_numRows ($result) == 1) {
                 $A = DB_fetchArray ($result);
@@ -451,7 +456,7 @@ default:
     }
     if (!empty ($eid)) {
         if (($mode == 'personal') && ($_CAJP_CONF['personalcalendars'] == 1) &&
-                (isset ($_USER['uid']) && ($_USER['uid'] > 1))) {
+                !COM_isAnonUser()) {
             $datesql = "SELECT * FROM {$_TABLES['personal_eventsjp']} "
                      . "WHERE (eid = '$eid') AND (uid = {$_USER['uid']})";
             $pagetitle = $LANG_CALJP_2[28] . ' ' . COM_getDisplayName();
@@ -465,6 +470,15 @@ default:
             DB_query ("UPDATE {$_TABLES['eventsjp']} SET hits = hits + 1 WHERE eid = '$eid'");
         }
 
+        if (($mode == 'personal') && ($_CAJP_CONF['personalcalendars'] == 1) &&
+                !COM_isAnonUser()) {
+            $event_title = DB_getItem($_TABLES['personal_eventsjp'],
+                           'title', "(eid = '$eid') AND (uid = {$_USER['uid']})");
+        } else {
+            $event_title = DB_getItem($_TABLES['eventsjp'], 'title', "eid = '$eid'");
+        }
+        $pagetitle = stripslashes($event_title) . ' - ' . $pagetitle;
+
         $display .= COM_siteHeader('menu', $pagetitle);
         if (isset($_GET['msg'])) {
             $msg = COM_applyFilter($_GET['msg'], true);
@@ -504,14 +518,14 @@ default:
                  . "and DATE_FORMAT(dateend,'%Y-%m-%d') "
                  . "ORDER BY datestart ASC,timestart ASC,title";
     }
-    $cal_templates = new Template($_CONF['path'] . 'plugins/calendarjp/templates/');
+    $ja = ($_CONF['language'] == 'japanese_utf-8');
+    $cal_templates = COM_newTemplate($_CONF['path'] . 'plugins/calendarjp/templates/');
     $cal_templates->set_file (array (
-            'events'    => 'events.thtml',
+            'events'    => 'events' . ($ja ? '_ja' : '') . '.thtml',
             'details'   => 'eventdetails.thtml',
             'addremove' => 'addremoveevent.thtml'
             ));
 
-    $cal_templates->set_var ( 'xhtml', XHTML );
     $cal_templates->set_var ('lang_addevent', $LANG_CALJP_1[6]);
     $cal_templates->set_var ('lang_backtocalendar', $LANG_CALJP_1[15]);
     if ($mode == 'personal') {
@@ -526,9 +540,6 @@ default:
         $cal_templates->set_var('lang_month','');
         $cal_templates->set_var('event_year','');
         $cal_templates->set_var('event_details','');
-        $cal_templates->set_var('site_url', $_CONF['site_url']);
-        $cal_templates->set_var('site_admin_url', $_CONF['site_admin_url']);
-        $cal_templates->set_var('layout_url', $_CONF['layout_url']);
         $cal_templates->parse('output','events');
         $display .= $cal_templates->finish($cal_templates->get_var('output'));
         $display .= $LANG_CALJP_1[2];
@@ -536,26 +547,43 @@ default:
         $cal = new Calendar();
         setCalendarLanguage ($cal);
 
+        require_once $_CONF['path'] . 'plugins/calendarjp/include/gltext.class.php';
+        $gltext = new GLText();
+
         $currentmonth = '';
         for ($i = 0; $i < $nrows; $i++) {
             $A = DB_fetchArray($result);
             if (SEC_hasAccess($A['owner_id'],$A['group_id'],$A['perm_owner'],
                               $A['perm_group'],$A['perm_members'],$A['perm_anon']) > 0) {
+                $cal_templates->set_var('lang_owner', $LANG_ACCESS['owner']);
+                $ownername = COM_getDisplayName($A['owner_id']);
+                $cal_templates->set_var('owner_name', $ownername);
+                $cal_templates->set_var('owner_id', $A['owner_id']);
+
                 if (strftime('%B',strtotime($A['datestart'])) != $currentmonth) {
                     $str_month = $cal->getMonthName(strftime('%m',strtotime($A['datestart'])));
                     $cal_templates->set_var('lang_month', $str_month);
                     $cal_templates->set_var('event_year', strftime('%Y',strtotime($A['datestart'])));
                     $currentmonth = strftime('%B',strtotime($A['datestart']));
                 }
-                $cal_templates->set_var('event_title', stripslashes($A['title']));
-                $cal_templates->set_var('site_url', $_CONF['site_url']);
-                $cal_templates->set_var('site_admin_url', $_CONF['site_admin_url']);
-                $cal_templates->set_var('layout_url', $_CONF['layout_url']);
+
                 $event_title = stripslashes($A['title']);
                 if (!empty($A['url'])) {
-                    $event_title = COM_createLink($event_title, $A['url']);
+                    $event_title_and_url = COM_createLink($event_title,
+                                            $A['url'], array('class' => 'url'));
+                    $cal_templates->set_var('event_url', $A['url']);
+                    $cal_templates->set_var('event_begin_anchortag',
+                        '<a href="' . $A['url'] . '" class="url">');
+                    $cal_templates->set_var('event_end_anchortag', '</a>');
+                } else {
+                    $event_title_and_url = $event_title;
+                    $cal_templates->set_var('event_url', '');
+                    $cal_templates->set_var('event_begin_anchortag', '');
+                    $cal_templates->set_var('event_end_anchortag', '');
                 }
-                $cal_templates->set_var('event_title', $event_title);
+                $cal_templates->set_var('event_title', $event_title_and_url);
+                $cal_templates->set_var('event_title_only', $event_title);
+
                 if (($_CAJP_CONF['personalcalendars'] == 1)
                         && !COM_isAnonUser()) {
                     $tmpresult = DB_query("SELECT * FROM {$_TABLES['personal_eventsjp']} WHERE eid='{$A['eid']}' AND uid={$_USER['uid']}");
@@ -665,17 +693,14 @@ default:
                 }
 
                 $cal_templates->set_var('lang_description', $LANG_CALJP_1[5]);
-                $description = stripslashes($A['description']);
-                if (empty($A['postmode']) || ($A['postmode'] == 'plaintext')) {
-                    $description = nl2br($description);
-                }
-                $description = PLG_replaceTags($description);
+                $description = $gltext->getDisplayText($A['description'], $A['postmode']);
                 if (!empty($query)) {
                     $description = COM_highlightQuery($description, $query);
                 }
                 $cal_templates->set_var ('event_description', $description);
                 $cal_templates->set_var ('lang_event_type', $LANG_CALJP_1[37]);
                 $cal_templates->set_var ('event_type', $A['event_type']);
+                $cal_templates->set_var ('event_id', $A['eid']);
 
                 if ($mode == 'personal') {
                     $editurl = $_CONF['site_url']
@@ -728,6 +753,6 @@ default:
 
 } // end switch
 
-echo $display;
+COM_output($display);
 
 ?>
